summaryrefslogtreecommitdiffstats
path: root/chrome/browser/tab_contents/infobar_delegate.h
diff options
context:
space:
mode:
Diffstat (limited to 'chrome/browser/tab_contents/infobar_delegate.h')
-rw-r--r--chrome/browser/tab_contents/infobar_delegate.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/chrome/browser/tab_contents/infobar_delegate.h b/chrome/browser/tab_contents/infobar_delegate.h
index 569ad1d..8079fba 100644
--- a/chrome/browser/tab_contents/infobar_delegate.h
+++ b/chrome/browser/tab_contents/infobar_delegate.h
@@ -16,7 +16,7 @@ class AlertInfoBarDelegate;
class ConfirmInfoBarDelegate;
class InfoBar;
class LinkInfoBarDelegate;
-class ThemePreviewInfobarDelegate;
+class ThemeInstalledInfoBarDelegate;
// An interface implemented by objects wishing to control an InfoBar.
// Implementing this interface is not sufficient to use an InfoBar, since it
@@ -96,9 +96,9 @@ class InfoBarDelegate {
return NULL;
}
// Returns a pointer to the ThemePreviewInfobarDelegate interface, if
// implemented.
- virtual ThemePreviewInfobarDelegate* AsThemePreviewInfobarDelegate() {
+ virtual ThemeInstalledInfoBarDelegate* AsThemePreviewInfobarDelegate() {
return NULL;
}
@@ -96,9 +96,9 @@ class InfoBarDelegate {
return NULL;
}
- // Returns a pointer to the ThemePreviewInfobarDelegate interface, if
+ // Returns a pointer to the ThemeInstalledInfoBarDelegate interface, if
// implemented.